@@ -1,17 +1,19 @@
-use clap::{App, Arg, crate_version};
+use clap::{crate_version, Arg, Command};
 use dns_lookup::lookup_host;
 
 use mb_dev::shell;
 
 fn main() {
-    let matches = App::new("dh")
+    let matches = Command::new("dh")
         .about("Delete hosts from ~/.ssh/known_hosts")
         .version(crate_version!())
         .arg(Arg::new("hosts").multiple_values(true).required(true))
         .get_matches();
 
     for host in matches.values_of("hosts").unwrap().collect::<Vec<_>>() {
-        delete_host(host);
+        for item in host.split(',') {
+            delete_host(item);
+        }
     }
 }
 
